/*
 * "Copyright (c) 2013   Capgemini Technology Services (hereinafter "Capgemini")
 *
 * License/Terms of Use
 * Permission is hereby granted, free of charge and for the term of intellectual
 * property rights on the Software, to any person obtaining a copy of this software
 * and associated documentation files (the "Software"), to use, copy, modify and
 * propagate free of charge, anywhere in the world, all or part of the Software
 * subject to the following mandatory conditions:
 *
 * -   The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * Any failure to comply with the above shall automatically terminate the license
 * and be construed as a breach of these Terms of Use causing significant harm to
 * Capgemini.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, PEACEFUL ENJOYMENT,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 * OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of Capgemini shall not be used in
 * advertising or otherwise to promote the use or other dealings in this Software
 * without prior written authorization from Capgemini.
 *
 * These Terms of Use are subject to French law.
 *
 * IMPORTANT NOTICE: The WUIC software implements software components governed by
 * open source software licenses (BSD and Apache) of which CAPGEMINI is not the
 * author or the editor. The rights granted on the said software components are
 * governed by the specific terms and conditions specified by Apache 2.0 and BSD
 * licenses."
 */


package com.github.wuic.helper.configuration;

import com.github.wuic.FileType;
import com.github.wuic.resource.impl.FileWuicResource;
import com.github.wuic.resource.WuicResource;
import com.github.wuic.configuration.SourceRootProvider;
import com.github.wuic.servlet.WuicServlet;

import java.io.IOException;

/**
 * <p>
 * A {@link SourceRootProvider} which takes resources exposed through the servlet context.
 * </p>
 *
 * @author Guillaume DROUET
 * @version 1.0
 * @since 0.3.0
 */
public class WebappSourceRootProvider implements SourceRootProvider {

    /**
     * {@inheritDoc}
     */
    @Override
    public WuicResource getStreamResource(final String groupId, final String file) throws IOException {
        final String ext = file.substring(file.lastIndexOf('.'));
        final String realPath = WuicServlet.servletContext().getRealPath(file);
        final FileType type = FileType.getFileTypeForExtension(ext);

        // Remove the file name in the path
        int rpIndex = realPath.lastIndexOf(file);

        // Manage case of windows file system
        if (rpIndex == -1) {
            rpIndex = realPath.lastIndexOf(file.replace('/', '\\'));
        }

        return new FileWuicResource(realPath.substring(0, rpIndex), file, type);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Boolean hasChanged(final String groupId, final String file, final Long timestamp) {
        return Boolean.FALSE;
    }
}
